@@ -39,7 +39,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddSmsSign", params)
+            headers = request.headers
+            body = self.call("AddSmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddSmsSignResponse()
@@ -58,8 +59,8 @@ class SmsClient(AbstractClient):
 
 
     def AddSmsTemplate(self, request):
-        """1. 添加短信模版，申请之前请先认真参阅 [腾讯云短信正文模版审核标准](https://cloud.tencent.com/document/product/382/39023)。
-        2. ⚠️注意：个人认证用户不支持使用 API 申请短信正文模版，请参阅了解 [实名认证基本介绍](https://cloud.tencent.com/document/product/378/3629)，如果为个人认证请登录 [控制台](https://console.cloud.tencent.com/smsv2) 申请短信正文模版。
+        """1. 添加短信模板，申请之前请先认真参阅 [腾讯云短信正文模板审核标准](https://cloud.tencent.com/document/product/382/39023)。
+        2. ⚠️注意：个人认证用户不支持使用 API 申请短信正文模板，请参阅了解 [实名认证基本介绍](https://cloud.tencent.com/document/product/378/3629)，如果为个人认证请登录 [控制台](https://console.cloud.tencent.com/smsv2) 申请短信正文模板。
         >- 注：由于云 **API3.0 安全性**有所提升，所以**接口鉴权**较为复杂，建议使用 [SDK](https://cloud.tencent.com/document/product/382/43193) 来使用云短信服务。
         >- 您可以在 [API 3.0 Explorer](https://console.cloud.tencent.com/api/explorer?Product=sms&Version=2019-07-11&Action=SendSms) 中直接运行该接口，可以先免去签名计算步骤。运行成功后，API Explorer可以**自动生成**SDK代码示例。
 
@@ -70,7 +71,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddSmsTemplate", params)
+            headers = request.headers
+            body = self.call("AddSmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddSmsTemplateResponse()
@@ -100,7 +102,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CallbackStatusStatistics", params)
+            headers = request.headers
+            body = self.call("CallbackStatusStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CallbackStatusStatisticsResponse()
@@ -130,7 +133,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSmsSign", params)
+            headers = request.headers
+            body = self.call("DeleteSmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSmsSignResponse()
@@ -149,7 +153,7 @@ class SmsClient(AbstractClient):
 
 
     def DeleteSmsTemplate(self, request):
-        """⚠️注意：个人认证用户不支持使用 API 删除短信正文模版，请登录 [控制台](https://console.cloud.tencent.com/smsv2) 删除短信正文模版，如需了解请参阅 [实名认证基本介绍](https://cloud.tencent.com/document/product/378/3629)。
+        """⚠️注意：个人认证用户不支持使用 API 删除短信正文模板，请登录 [控制台](https://console.cloud.tencent.com/smsv2) 删除短信正文模板，如需了解请参阅 [实名认证基本介绍](https://cloud.tencent.com/document/product/378/3629)。
         >- 注：由于云 **API3.0 安全性**有所提升，所以**接口鉴权**较为复杂，建议使用 [SDK](https://cloud.tencent.com/document/product/382/43193) 来使用云短信服务。
         >- 您可以在 [API 3.0 Explorer](https://console.cloud.tencent.com/api/explorer?Product=sms&Version=2019-07-11&Action=SendSms) 中直接运行该接口，可以先免去签名计算步骤。运行成功后，API Explorer可以**自动生成**SDK代码示例。
 
@@ -160,7 +164,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSmsTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteSmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSmsTemplateResponse()
@@ -190,7 +195,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSmsSignList", params)
+            headers = request.headers
+            body = self.call("DescribeSmsSignList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSmsSignListResponse()
@@ -209,7 +215,7 @@ class SmsClient(AbstractClient):
 
 
     def DescribeSmsTemplateList(self, request):
-        """⚠️注意：个人认证用户不支持使用 API 查询短信正文模版，请参阅了解 [实名认证基本介绍](https://cloud.tencent.com/document/product/378/3629)。
+        """⚠️注意：个人认证用户不支持使用 API 查询短信正文模板，请参阅了解 [实名认证基本介绍](https://cloud.tencent.com/document/product/378/3629)。
         >- 注：由于云 **API3.0 安全性**有所提升，所以**接口鉴权**较为复杂，建议使用 [SDK](https://cloud.tencent.com/document/product/382/43193) 来使用云短信服务。
         >- 您可以在 [API 3.0 Explorer](https://console.cloud.tencent.com/api/explorer?Product=sms&Version=2019-07-11&Action=SendSms) 中直接运行该接口，可以先免去签名计算步骤。运行成功后，API Explorer可以**自动生成**SDK代码示例。
 
@@ -220,7 +226,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSmsTemplateList", params)
+            headers = request.headers
+            body = self.call("DescribeSmsTemplateList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSmsTemplateListResponse()
@@ -252,7 +259,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySmsSign", params)
+            headers = request.headers
+            body = self.call("ModifySmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySmsSignResponse()
@@ -271,9 +279,9 @@ class SmsClient(AbstractClient):
 
 
     def ModifySmsTemplate(self, request):
-        """1. 修改短信正文模版，修改之前请先认真参阅 [腾讯云短信正文模版审核标准](https://cloud.tencent.com/document/product/382/39023)。
-        2. ⚠️注意：个人认证用户不支持使用 API 修改短信正文模版，请参阅了解 [实名认证基本介绍](https://cloud.tencent.com/document/product/378/3629)，如果为个人认证请登录 [控制台](https://console.cloud.tencent.com/smsv2) 修改短信正文模版。
-        3. 修改短信模板，仅当正文模版为**待审核**或**已拒绝**状态时，才能进行修改，**已审核通过**的正文模版不支持修改。
+        """1. 修改短信正文模板，修改之前请先认真参阅 [腾讯云短信正文模板审核标准](https://cloud.tencent.com/document/product/382/39023)。
+        2. ⚠️注意：个人认证用户不支持使用 API 修改短信正文模板，请参阅了解 [实名认证基本介绍](https://cloud.tencent.com/document/product/378/3629)，如果为个人认证请登录 [控制台](https://console.cloud.tencent.com/smsv2) 修改短信正文模板。
+        3. 修改短信模板，仅当正文模板为**待审核**或**已拒绝**状态时，才能进行修改，**已审核通过**的正文模板不支持修改。
         >- 注：由于云 **API3.0 安全性**有所提升，所以**接口鉴权**较为复杂，建议使用 [SDK](https://cloud.tencent.com/document/product/382/43193) 来使用云短信服务。
         >- 您可以在 [API 3.0 Explorer](https://console.cloud.tencent.com/api/explorer?Product=sms&Version=2019-07-11&Action=SendSms) 中直接运行该接口，可以先免去签名计算步骤。运行成功后，API Explorer可以**自动生成**SDK代码示例。
 
@@ -284,7 +292,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySmsTemplate", params)
+            headers = request.headers
+            body = self.call("ModifySmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySmsTemplateResponse()
@@ -316,7 +325,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsReplyStatus", params)
+            headers = request.headers
+            body = self.call("PullSmsReplyStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsReplyStatusResponse()
@@ -347,7 +357,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsReplyStatusByPhoneNumber", params)
+            headers = request.headers
+            body = self.call("PullSmsReplyStatusByPhoneNumber", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsReplyStatusByPhoneNumberResponse()
@@ -379,7 +390,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsSendStatus", params)
+            headers = request.headers
+            body = self.call("PullSmsSendStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsSendStatusResponse()
@@ -410,7 +422,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsSendStatusByPhoneNumber", params)
+            headers = request.headers
+            body = self.call("PullSmsSendStatusByPhoneNumber", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsSendStatusByPhoneNumberResponse()
@@ -440,7 +453,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SendSms", params)
+            headers = request.headers
+            body = self.call("SendSms", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SendSmsResponse()
@@ -470,7 +484,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SendStatusStatistics", params)
+            headers = request.headers
+            body = self.call("SendStatusStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SendStatusStatisticsResponse()
@@ -500,7 +515,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SmsPackagesStatistics", params)
+            headers = request.headers
+            body = self.call("SmsPackagesStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SmsPackagesStatisticsResponse()
